function policy = FW_MDP_policy(S,A,P,U)
% FW_MDP_policy - generate a policy from utilities
% See p. 648 Russell & Norvig
% On input:
%     S (vector): states (1 to n)
%     A (vector): actions (1 to k)
%     P (nxk array): transition model
%     U (vector): state utilities
% On output:
%     policy (vector): actions per state
% Call:
%     p = FW_MDP_policy(S,A,P,U);
% Author:
%     T. Henderson
%     UU
%     Summer 2018
%

num_actions = length(A);
num_states = length(S);
policy = zeros(1,num_states);

for s = 1:num_states
    A_max = -Inf;
    A_index = 0;
    for a = 1:num_actions
        val = 0;
        r = feval(P,S(s,:),A(a),1);
        num_r = length(r);
        for t = 1:num_r
            p_r = r(t).state_prob(1);
            v_r = r(t).state_prob(2);
            n_r = r(t).state_prob(3);
            d_r = r(t).state_prob(4);
            p_p = r(t).state_prob(5);
            sa = find(S(:,1)==p_r&S(:,2)==v_r&S(:,3)==n_r&S(:,4)==d_r);
            if ~isempty(sa)
                val = val + r(t).state_prob(end)*U(sa);
            end
        end
        if val>A_max
            A_max = val;
            A_index = a;
        end
    end
    policy(s) = A_index;
end
