function [U,U_trace,dt] = FW_MDP_value_iteration(S,A,P,R,gamma,eta,...
    max_iter)
% FW_MDP_value_iteration - compute policy using value iteration
% On input:
%     S (vector): states (1 to n)
%     A (vector): actions (1 to k)
%     P (nxk array): transition model
%     R (vector): state rewards
%     gamma (float): discount factor
%     eta (float): termination threshold
%     max_iter (int): max number of iterations
% On output:
%     U (vector): state utilities
%     U_trace (iterxn): trace of utility values during iteration
% Call:
% Chapter 17 Russell and Norvig (Table p. 651)
% [S,A,R,P,U,Ut] = FW_run_value_iteration(S,A,P,R,0.999999,0.1,100)
% Author:
%     T. Henderson
%     UU
%     Summer 2018
%

dt = [];
num_states = length(S);
num_actions = length(A);
U = zeros(1,num_states);
U_p = U;

U_trace = [];

done = 0;
iter  = 0;
wb = waitbar(0,'Trader MDP');
while done==0
    iter = iter + 1;
    waitbar(iter/max_iter);
    U = U_p;
    delta = 0;
    for s = 1:num_states
        A_ind = 0;
        A_max = -Inf;
        for a = 1:num_actions
            val = 0;
            r = feval(P,S(s,:),A(a),1);
            num_r = length(r);
            for t = 1:num_r
                p_r = r(t).state_prob(1);
                v_r = r(t).state_prob(2);
                n_r = r(t).state_prob(3);
                d_r = r(t).state_prob(4);
                p_p = r(t).state_prob(5);
                sa = find(S(:,1)==p_r&S(:,2)==v_r&S(:,3)==n_r&S(:,4)==d_r);
                if ~isempty(sa)
                    val = val + r(t).state_prob(end)*U(sa);
                end
            end
            if val>A_max
                A_ind = a;
                A_max = val;
            end
        end
        U_p(s) = R(s) + gamma*A_max;
        if abs(U_p(s)-U(s))>delta
            delta = abs(U_p(s)-U(s));
        end
    end
    U_trace = [U_trace;U_p];
    dt = [dt;delta];
    if delta<eta*(1-gamma)/gamma||(iter>max_iter)
        done = 1;
    end
end
close(wb);
