function r = FW_P(s,a,dir)
% FW_P - state-action transition function
% On input:
%     s (int): state index
%     a (int): action index
%     dir (int): market going up (1) or down (-1)
% On output:
%     r (state-prob struct): has set of possible next states & their probs
%      (k).state_prob (1x5 vector): p, v, n, d, prob
%         p (int): asset price
%         v (int): value
%         n (int): number of asset
%         d (int): dollars
%         prob (float): probability of transitioning to this state
% Call:
%     r = FW_P(18,1,1);
% Author:
%     T. Henderson
%     UU
%     Summer 2018
%

SWITCH_PERCENT = 0.1;

p = s(1);
v = s(2);
n = s(3);
d = s(4);

if a==1&d>=p
    n_next = n + 1;
    d_next = d - p;
elseif a==2&n>0&(d+p)<100
    n_next = n - 1;
    d_next = d + p;
else
    n_next = n;
    d_next = d;
end

if dir>0
    r(1).state_prob = [min(100,p+10),-1,n_next,d_next,1-SWITCH_PERCENT];
    r(2).state_prob = [max(10,p-10),1,n_next,d_next,SWITCH_PERCENT];
else
    r(1).state_prob = [max(10,p-10),1,n_next,d_next,1-SWITCH_PERCENT];
    r(2).state_prob = [min(100,p+10),-1,n_next,d_next,SWITCH_PERCENT];
end
