function dt = FW_run_trader(S,A,R,P,pol,max_iter)
% FW_run_trader  - use policies in a simulation
% On input:
%     S (nx4 array): states
%     A (1x2 vector): actions
%     R (nx1 vector): rewards
%     pol (nx1 vector): policy (action for each state)
%     max_iter (int): time steps for simulation
% On output:
%     dt (max_iterx6 array): trace of simulation
%       col 1: asset price
%       col 2: value
%       col 3: number of assets owned
%       col 4: dollars
%       col 5: direction of market
%       col 6: current wealth (d + p*n)
% Call:
%     dt = FW_run_trader(S,A,R,P,pol,max_iter);
% Author:
%     T. Henderson
%     UU
%     Summer 2018
%

% initialize world

N = 100;
p = 10;
v = 1;
n = 0;
d = 100;
dir = 1;
s = find(S(:,1)==p&S(:,2)==v&S(:,3)==n&S(:,4)==d);

dt = [p,v,n,d,dir,R(s)];

% run trader

iter = 0;
while iter<max_iter
    iter = iter + 1;
    s = find(S(:,1)==p&S(:,2)==v&S(:,3)==n&S(:,4)==d);
    a = pol(s);
%    a = mod(a,2) + 1;
    try
    r = feval(P,S(s,:),A(a),dir);
    catch
        tch = 0;
    end
    if rand<r(2).state_prob(end)
        dir = -dir;
        p = r(2).state_prob(1);
        v = r(2).state_prob(2);
        n = r(2).state_prob(3);
        d = r(2).state_prob(4);
    else
        p = r(1).state_prob(1);
        v = r(1).state_prob(2);
        n = r(1).state_prob(3);
        d = r(1).state_prob(4);
    end
    dt = [dt;p,v,n,d,dir,R(s)];
end
